@@ -61,8 +61,8 @@ class BrowserManagementKeywords(LibraryComponent):
         url: Optional[str] = None,
         browser: str = "firefox",
         alias: Optional[str] = None,
-        remote_url: Union[str, bool] = False,
-        desired_capabilities: Union[str, dict, None] = None,
+        remote_url: Union[bool, str] = False,
+        desired_capabilities: Union[dict, None, str] = None,
         ff_profile_dir: Optional[str] = None,
         options: Any = None,
         service_log_path: Optional[str] = None,
