@@ -13,19 +13,46 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-
 from datetime import datetime
+from typing import Union, Optional
 
 from robot.libraries.DateTime import convert_date
-from robot.utils import DotDict
+from robot.utils import DotDict, is_truthy
 
 from SeleniumLibrary.base import LibraryComponent, keyword
 from SeleniumLibrary.errors import CookieNotFound
-from SeleniumLibrary.utils import is_truthy, is_noney, is_falsy
+
+
+class CookieInformation:
+    def __init__(
+        self,
+        name,
+        value,
+        path=None,
+        domain=None,
+        secure=False,
+        httpOnly=False,
+        expiry=None,
+        **extra,
+    ):
+        self.name = name
+        self.value = value
+        self.path = path
+        self.domain = domain
+        self.secure = secure
+        self.httpOnly = httpOnly
+        self.expiry = datetime.fromtimestamp(expiry) if expiry else None
+        self.extra = extra
+
+    def __str__(self):
+        items = "name value path domain secure httpOnly expiry".split()
+        string = "\n".join(f"{item}={getattr(self, item)}" for item in items)
+        if self.extra:
+            string = f"{string}\nextra={self.extra}\n"
+        return string
 
 
 class CookieKeywords(LibraryComponent):
-
     @keyword
     def delete_all_cookies(self):
         """Deletes all cookies."""
@@ -40,7 +67,7 @@ class CookieKeywords(LibraryComponent):
         self.driver.delete_cookie(name)
 
     @keyword
-    def get_cookies(self, as_dict=False):
+    def get_cookies(self, as_dict: bool = False) -> Union[str, dict]:
         """Returns all cookies of the current page.
 
         If ``as_dict`` argument evaluates as false, see `Boolean arguments`
@@ -55,19 +82,19 @@ class CookieKeywords(LibraryComponent):
 
         The `` as_dict`` argument is new in SeleniumLibrary 3.3
         """
-        if is_falsy(as_dict):
+        if not as_dict:
             pairs = []
             for cookie in self.driver.get_cookies():
-                pairs.append(cookie['name'] + "=" + cookie['value'])
-            return '; '.join(pairs)
+                pairs.append(f"{cookie['name']}={cookie['value']}")
+            return "; ".join(pairs)
         else:
             pairs = DotDict()
             for cookie in self.driver.get_cookies():
-                pairs[cookie['name']] = cookie['value']
+                pairs[cookie["name"]] = cookie["value"]
             return pairs
 
     @keyword
-    def get_cookie(self, name):
+    def get_cookie(self, name: str) -> CookieInformation:
         """Returns information of cookie with ``name`` as an object.
 
         If no cookie is found with ``name``, keyword fails. The cookie object
@@ -109,12 +136,19 @@ class CookieKeywords(LibraryComponent):
         """
         cookie = self.driver.get_cookie(name)
         if not cookie:
-            raise CookieNotFound("Cookie with name '%s' not found." % name)
+            raise CookieNotFound(f"Cookie with name '{name}' not found.")
         return CookieInformation(**cookie)
 
     @keyword
-    def add_cookie(self, name, value, path=None, domain=None, secure=None,
-                   expiry=None):
+    def add_cookie(
+        self,
+        name: str,
+        value: str,
+        path: Optional[str] = None,
+        domain: Optional[str] = None,
+        secure: Optional[bool] = None,
+        expiry: Optional[str] = None,
+    ):
         """Adds a cookie to your current session.
 
         ``name`` and ``value`` are required, ``path``, ``domain``, ``secure``
@@ -130,42 +164,20 @@ class CookieKeywords(LibraryComponent):
 
         Prior to SeleniumLibrary 3.0 setting expiry did not work.
         """
-        new_cookie = {'name': name, 'value': value}
-        if not is_noney(path):
-            new_cookie['path'] = path
-        if not is_noney(domain):
-            new_cookie['domain'] = domain
+        new_cookie = {"name": name, "value": value}
+        if path is not None:
+            new_cookie["path"] = path
+        if domain is not None:
+            new_cookie["domain"] = domain
         # Secure must be True or False
-        if not is_noney(secure):
-            new_cookie['secure'] = is_truthy(secure)
-        if not is_noney(expiry):
-            new_cookie['expiry'] = self._expiry(expiry)
+        if secure is not None:
+            new_cookie["secure"] = secure
+        if expiry is not None:
+            new_cookie["expiry"] = self._expiry(expiry)
         self.driver.add_cookie(new_cookie)
 
     def _expiry(self, expiry):
         try:
             return int(expiry)
-        except ValueError:
-            return int(convert_date(expiry, result_format='epoch'))
-
-
-class CookieInformation(object):
-
-    def __init__(self, name, value, path=None, domain=None, secure=False,
-                 httpOnly=False, expiry=None, **extra):
-        self.name = name
-        self.value = value
-        self.path = path
-        self.domain = domain
-        self.secure = secure
-        self.httpOnly = httpOnly
-        self.expiry = datetime.fromtimestamp(expiry) if expiry else None
-        self.extra = extra
-
-    def __str__(self):
-        items = 'name value path domain secure httpOnly expiry'.split()
-        string = '\n'.join('%s=%s' % (item, getattr(self, item))
-                           for item in items)
-        if self.extra:
-            string = '%s\n%s=%s\n' % (string, 'extra', self.extra)
-        return string
+        except (ValueError, TypeError):
+            return int(convert_date(expiry, result_format="epoch"))
