@@ -13,8 +13,9 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from typing import List, Optional
+from typing import List, Optional, Union
 
+from selenium.webdriver.remote.webelement import WebElement
 from selenium.webdriver.support.ui import Select
 
 from SeleniumLibrary.base import LibraryComponent, keyword
@@ -23,7 +24,9 @@ from SeleniumLibrary.utils import is_truthy, plural_or_not
 
 class SelectElementKeywords(LibraryComponent):
     @keyword
-    def get_list_items(self, locator: str, values: bool = False) -> List[str]:
+    def get_list_items(
+        self, locator: Union[WebElement, str], values: bool = False
+    ) -> List[str]:
         """Returns all labels or values of selection list ``locator``.
 
         See the `Locating elements` section for details about the locator
@@ -46,7 +49,7 @@ class SelectElementKeywords(LibraryComponent):
             return self._get_labels(options)
 
     @keyword
-    def get_selected_list_label(self, locator: str) -> str:
+    def get_selected_list_label(self, locator: Union[WebElement, str]) -> str:
         """Returns the label of selected option from selection list ``locator``.
 
         If there are multiple selected options, the label of the first option
@@ -59,7 +62,7 @@ class SelectElementKeywords(LibraryComponent):
         return select.first_selected_option.text
 
     @keyword
-    def get_selected_list_labels(self, locator: str) -> List[str]:
+    def get_selected_list_labels(self, locator: Union[WebElement, str]) -> List[str]:
         """Returns labels of selected options from selection list ``locator``.
 
         Starting from SeleniumLibrary 3.0, returns an empty list if there
@@ -72,7 +75,7 @@ class SelectElementKeywords(LibraryComponent):
         return self._get_labels(options)
 
     @keyword
-    def get_selected_list_value(self, locator: str) -> str:
+    def get_selected_list_value(self, locator: Union[WebElement, str]) -> str:
         """Returns the value of selected option from selection list ``locator``.
 
         If there are multiple selected options, the value of the first option
@@ -85,7 +88,7 @@ class SelectElementKeywords(LibraryComponent):
         return select.first_selected_option.get_attribute("value")
 
     @keyword
-    def get_selected_list_values(self, locator: str) -> List[str]:
+    def get_selected_list_values(self, locator: Union[WebElement, str]) -> List[str]:
         """Returns values of selected options from selection list ``locator``.
 
         Starting from SeleniumLibrary 3.0, returns an empty list if there
@@ -98,7 +101,7 @@ class SelectElementKeywords(LibraryComponent):
         return self._get_values(options)
 
     @keyword
-    def list_selection_should_be(self, locator: str, *expected: str):
+    def list_selection_should_be(self, locator: Union[WebElement, str], *expected: str):
         """Verifies selection list ``locator`` has ``expected`` options selected.
 
         It is possible to give expected options both as visible labels and
@@ -135,7 +138,7 @@ class SelectElementKeywords(LibraryComponent):
         return " | ".join(f"{label} ({value})" for label, value in zip(labels, values))
 
     @keyword
-    def list_should_have_no_selections(self, locator: str):
+    def list_should_have_no_selections(self, locator: Union[WebElement, str]):
         """Verifies selection list ``locator`` has no options selected.
 
         See the `Locating elements` section for details about the locator
@@ -154,7 +157,10 @@ class SelectElementKeywords(LibraryComponent):
 
     @keyword
     def page_should_contain_list(
-        self, locator: str, message: Optional[str] = None, loglevel: str = "TRACE"
+        self,
+        locator: Union[WebElement, str],
+        message: Optional[str] = None,
+        loglevel: str = "TRACE",
     ):
         """Verifies selection list ``locator`` is found from current page.
 
@@ -168,7 +174,10 @@ class SelectElementKeywords(LibraryComponent):
 
     @keyword
     def page_should_not_contain_list(
-        self, locator: str, message: Optional[str] = None, loglevel: str = "TRACE"
+        self,
+        locator: Union[WebElement, str],
+        message: Optional[str] = None,
+        loglevel: str = "TRACE",
     ):
         """Verifies selection list ``locator`` is not found from current page.
 
@@ -181,7 +190,7 @@ class SelectElementKeywords(LibraryComponent):
         self.assert_page_not_contains(locator, "list", message, loglevel)
 
     @keyword
-    def select_all_from_list(self, locator: str):
+    def select_all_from_list(self, locator: Union[WebElement, str]):
         """Selects all options from multi-selection list ``locator``.
 
         See the `Locating elements` section for details about the locator
@@ -197,7 +206,7 @@ class SelectElementKeywords(LibraryComponent):
             select.select_by_index(index)
 
     @keyword
-    def select_from_list_by_index(self, locator: str, *indexes: str):
+    def select_from_list_by_index(self, locator: Union[WebElement, str], *indexes: str):
         """Selects options from selection list ``locator`` by ``indexes``.
 
         Indexes of list options start from 0.
@@ -222,7 +231,7 @@ class SelectElementKeywords(LibraryComponent):
             select.select_by_index(int(index))
 
     @keyword
-    def select_from_list_by_value(self, locator: str, *values: str):
+    def select_from_list_by_value(self, locator: Union[WebElement, str], *values: str):
         """Selects options from selection list ``locator`` by ``values``.
 
         If more than one option is given for a single-selection list,
@@ -244,7 +253,7 @@ class SelectElementKeywords(LibraryComponent):
             select.select_by_value(value)
 
     @keyword
-    def select_from_list_by_label(self, locator: str, *labels: str):
+    def select_from_list_by_label(self, locator: Union[WebElement, str], *labels: str):
         """Selects options from selection list ``locator`` by ``labels``.
 
         If more than one option is given for a single-selection list,
@@ -266,7 +275,7 @@ class SelectElementKeywords(LibraryComponent):
             select.select_by_visible_text(label)
 
     @keyword
-    def unselect_all_from_list(self, locator: str):
+    def unselect_all_from_list(self, locator: Union[WebElement, str]):
         """Unselects all options from multi-selection list ``locator``.
 
         See the `Locating elements` section for details about the locator
@@ -283,7 +292,9 @@ class SelectElementKeywords(LibraryComponent):
         select.deselect_all()
 
     @keyword
-    def unselect_from_list_by_index(self, locator: str, *indexes: str):
+    def unselect_from_list_by_index(
+        self, locator: Union[WebElement, str], *indexes: str
+    ):
         """Unselects options from selection list ``locator`` by ``indexes``.
 
         Indexes of list options start from 0. This keyword works only with
@@ -308,7 +319,9 @@ class SelectElementKeywords(LibraryComponent):
             select.deselect_by_index(int(index))
 
     @keyword
-    def unselect_from_list_by_value(self, locator: str, *values: str):
+    def unselect_from_list_by_value(
+        self, locator: Union[WebElement, str], *values: str
+    ):
         """Unselects options from selection list ``locator`` by ``values``.
 
         This keyword works only with multi-selection lists.
@@ -331,7 +344,9 @@ class SelectElementKeywords(LibraryComponent):
             select.deselect_by_value(value)
 
     @keyword
-    def unselect_from_list_by_label(self, locator: str, *labels: str):
+    def unselect_from_list_by_label(
+        self, locator: Union[WebElement, str], *labels: str
+    ):
         """Unselects options from selection list ``locator`` by ``labels``.
 
         This keyword works only with multi-selection lists.
@@ -353,14 +368,14 @@ class SelectElementKeywords(LibraryComponent):
         for label in labels:
             select.deselect_by_visible_text(label)
 
-    def _get_select_list(self, locator):
+    def _get_select_list(self, locator: Union[WebElement, str]):
         el = self.find_element(locator, tag="list")
         return Select(el)
 
-    def _get_options(self, locator):
+    def _get_options(self, locator: Union[WebElement, str]):
         return self._get_select_list(locator).options
 
-    def _get_selected_options(self, locator):
+    def _get_selected_options(self, locator: Union[WebElement, str]):
         return self._get_select_list(locator).all_selected_options
 
     def _get_labels(self, options):
